@@ -86,7 +86,7 @@ class ResponeResult():
 class ResponePageResult(ResponeResult):
     curCount = 0
     totalCount = 0
-    pageNO = 0
+    pageNo = 0
     pageSize = 0
     totalPage = 0
     nextPage = {}
@@ -99,26 +99,27 @@ class ResponePageResult(ResponeResult):
         self.msg = kwargs.get("msg")
         self.curCount = kwargs.get("curCount")
         self.totalCount = kwargs.get("totalCount")
-        self.pageNO = kwargs.get("pageNO")
+        self.pageNo = kwargs.get("pageNo")
         self.pageSize = kwargs.get("pageSize")
         self.totalPage = kwargs.get("totalPage")
 
-    def res_success(self, **args):
+    def res_success_paginate(self, **args):
+        items = args.get('items')
 
-        self.data = args.get('data', [])
+        self.data = [item.to_json() for item in items.items]
         self.code = args.get('code', ReturnCode.SUCCESS)
         self.msg = args.get('msg', 'success')
         self.status = args.get('status', True)
 
         self.curCount = args.get('curCount')
-        self.totalCount = args.get('totalCount')
-        self.pageNO = args.get('pageNO')
+        self.totalCount = args.get('totalCount', items.total)
+        self.pageNo = args.get('pageNo', items.page)
         self.pageSize = args.get('pageSize')
-        self.totalPage = args.get('totalPage')
+        self.totalPage = args.get('totalPage', items.pages)
 
-        return self.to_json()
+        return self.to_json_paginate()
     
-    def to_json(self):
+    def to_json_paginate(self):
         ret = {}
         ret["status"] = self.status
         ret["data"] = self.data
@@ -128,7 +129,7 @@ class ResponePageResult(ResponeResult):
 
         ret["curCount"] = self.curCount
         ret["totalCount"] = self.totalCount
-        ret["pageNO"] = self.pageNO
+        ret["pageNo"] = self.pageNo
         ret["pageSize"] = self.pageSize
         ret["totalPage"] = self.totalPage
         return ret
\ No newline at end of file
